from setuptools import setup

setup(name='shashipal',
      version='0.2',
      description='calculate library',
      packages=['shashipal'],
      author_email='admin@shashipal.me',
      zip_safe=False)